Name: ogre
Version: 1.6.4
Release: alt1
Summary: Object-Oriented Graphics Rendering Engine
# CC-BY-SA is for devel docs
License: LGPLv2+ and CC-BY-SA
Group: System/Libraries
Url: http://www.ogre3d.org/
Source: %name-%version.tar.bz2
Patch: %name-%version-alt-changes.patch
Packager: Slava Dubrovskiy <dubrsl@altlinux.ru>

BuildRequires: gcc-c++ cegui-devel zziplib-devel libfreetype-devel libgtk+2-devel libois-devel openexr-devel
BuildRequires: libXaw-devel libXrandr-devel libXxf86vm-devel libXext-devel libGLU-devel libfreeimage-devel tinyxml-devel
#BuildRequires:  glew-devel 

%description
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented,
flexible 3D engine written in C++ designed to make it easier and more
intuitive for developers to produce applications utilising
hardware-accelerated 3D graphics. The class library abstracts all the
details of using the underlying system libraries like Direct3D and
OpenGL and provides an interface based on world objects and other
intuitive classes.

%package -n lib%name
Summary: Object-oriented Graphics Rendering Engine (libraries)
Group: System/Libraries

%description -n lib%name
Ogre is a complete object-oriented 3D rendering engine. It supports
different rendering subsystems but only the OpenGL system is useful
for Linux.

This package contains the Ogre library and plugins.

%package -n lib%name-devel
Summary: Object-oriented Graphics Rendering Engine (development files)
Group: Development/C
Requires: lib%name = %version-%release

%description -n lib%name-devel
Ogre is a complete object-oriented 3D rendering engine. It supports
different rendering subsystems but only the OpenGL system is useful
for Linux.

This package contains the headers needed to develop with Ogre.

%package -n libceguiogrerenderer
Summary: CEGUI Ogre Renderer (libraries)
Group: System/Libraries

%description -n libceguiogrerenderer
Crazy Eddie's GUI System (or short CEGUI) is a cross platform free library
providing windowing and widgets. Or simply said: You can create GUI's with it.
The CEGUI Ogre Renderer purpose is to create user interfaces with Ogre.

This package contains the CEGUI Ogre Renderer library and plugins.

%package -n libceguiogrerenderer-devel
Summary: CEGUI Ogre Renderer (development files)
Group: Development/C
Requires: libceguiogrerenderer = %version-%release

%description -n libceguiogrerenderer-devel
Crazy Eddie's GUI System (or short CEGUI) is a cross platform free library
providing windowing and widgets. Or simply said: You can create GUI's with it.
The CEGUI Ogre Renderer purpose is to create user interfaces with Ogre.

This package contains the headers needed to develop with the CEGUI Ogre Renderer.

%package devel-doc
Summary: Ogre development documentation
Group: Development/Documentation
BuildArch: noarch

%description devel-doc
This package contains the Ogre API documentation and the Ogre development
manual. Install this package if you want to develop programs that use Ogre.

%package samples
Summary: Ogre samples executables and media
Group: Development/Other
Requires: %name = %version-%release

%description samples
This package contains the compiled (not the source) sample applications coming
with Ogre.  It also contains some media (meshes, textures,...) needed by these
samples. The samples are installed in %_libdir/Samples and can be executed
with the wrapper script called "Ogre-Samples".

%prep
%setup -q -n ogre
%patch -p1


%build
./bootstrap
%configure --disable-cg --enable-openexr
# --disable-ogre-demos
# --disable-devil
%make

%install
%make install DESTDIR=$RPM_BUILD_ROOT

# Create config for ldconfig
mkdir -p $RPM_BUILD_ROOT/etc/ld.so.conf.d
echo "%_libdir/OGRE" > $RPM_BUILD_ROOT/etc/ld.so.conf.d/%name-%_arch.conf

%__subst "s|../..|%_datadir/OGRE|g"  Samples/Common/bin/resources.cfg
sed -i '/CgProgramManager/s/Plugin=/#Plugin=/g' Samples/Common/bin/plugins.cfg

# Install the samples
mkdir -p $RPM_BUILD_ROOT%_libdir/OGRE/Samples
# The Sample binaries get installed into the buildroot in a subdir of
# the cwd??
cp -fR $RPM_BUILD_ROOT`pwd`/Samples/Common/bin/* \
  $RPM_BUILD_ROOT%_libdir/OGRE/Samples
for cfg in plugins.cfg media.cfg quake3settings.cfg resources.cfg; do
  install -p -m 644 Samples/Common/bin/$cfg \
    $RPM_BUILD_ROOT%_libdir/OGRE/Samples
done
sed -i 's|^PluginFolder=.*$|PluginFolder=%_libdir/OGRE|' \
    $RPM_BUILD_ROOT%_libdir/OGRE/Samples/plugins.cfg
# Change location of pak + switch from non-free chiropteraDM map
sed -i 's|^Pak0Location: ../../Media/.*$|Pak0Location: %_datadir/OGRE/Samples/Media/packs/ogretestmap.zip|' \
    $RPM_BUILD_ROOT%_libdir/OGRE/Samples/quake3settings.cfg
sed -i 's|^Map:.*$|Map: ogretestmap.bsp|' \
    $RPM_BUILD_ROOT%_libdir/OGRE/Samples/quake3settings.cfg
# Fixing bug with wrong case for media
#mv Samples/Media/PCZAppMedia/ROOM_NY.mesh Samples/Media/PCZAppMedia/room_ny.mesh
#mv Samples/Media/PCZAppMedia/ROOM_PY.mesh Samples/Media/PCZAppMedia/room_py.mesh
install -p -m 755 ogre-samples.sh $RPM_BUILD_ROOT%_bindir/Ogre-Samples

mkdir -p $RPM_BUILD_ROOT%_datadir/OGRE/Samples
cp -a Samples/Media $RPM_BUILD_ROOT%_datadir/OGRE/Samples
#ln -s ../../../../fonts/dejavu/DejaVuSans-Bold.ttf \
#  $RPM_BUILD_ROOT%_datadir/OGRE/Samples/Media/fonts/bluebold.ttf
#ln -s ../../../../fonts/dejavu/DejaVuSans.ttf \
#  $RPM_BUILD_ROOT%_datadir/OGRE/Samples/Media/fonts/bluehigh.ttf
#ln -s ../../../../fonts/dejavu/DejaVuSansCondensed.ttf \
#  $RPM_BUILD_ROOT%_datadir/OGRE/Samples/Media/fonts/bluecond.ttf
#ln -s ../../../../fonts/dejavu/DejaVuSans.ttf \
#  $RPM_BUILD_ROOT%_datadir/OGRE/Samples/Media/fonts/solo5.ttf

mkdir -p $RPM_BUILD_ROOT%_man1dir
install -p -m 644 OgreMaterialUpgrade.1 $RPM_BUILD_ROOT%_man1dir/OgreMaterialUpgrade.1
install -p -m 644 OgreMeshUpgrade.1 $RPM_BUILD_ROOT%_man1dir/OgreMeshUpgrade.1
install -p -m 644 OgreXMLConverter.1 $RPM_BUILD_ROOT%_man1dir/OgreXMLConverter.1

%files
%doc AUTHORS BUGS COPYING
%doc Docs/ChangeLog.html Docs/ReadMe.html Docs/style.css Docs/ogre-logo.gif
%_bindir/Ogre*
%_bindir/rcapsdump
%_libdir/OGRE/*.so
%_man1dir/*
%_datadir/OGRE
%exclude %_bindir/Ogre-Samples
%exclude %_libdir/OGRE/Samples
%exclude %_datadir/OGRE/Samples
/etc/ld.so.conf.d/*

%files -n lib%name
%_libdir/libOgre*-%version.so

%files  -n lib%name-devel
%_libdir/libOgreMain.so
%_libdir/pkgconfig/OGRE.pc
%_includedir/OGRE
%exclude %_includedir/OGRE/*CEGUI*

%files -n libceguiogrerenderer
%_libdir/libCEGUIOgre*-%version.so

%files -n libceguiogrerenderer-devel
%_libdir/libCEGUIOgreRenderer.so
%_libdir/pkgconfig/CEGUI-OGRE.pc
%_includedir/OGRE/*CEGUI*

%files devel-doc
%doc LINUX.DEV Docs/api Docs/manual Docs/vbo-update Docs/style.css

%files samples
%doc Samples/ReadMe.html
%_bindir/Ogre-Samples
%_libdir/OGRE/Samples
%_datadir/OGRE/Samples

%changelog
* Mon Oct 05 2009 Slava Dubrovskiy <dubrsl@altlinux.org> 1.6.4-alt1
- New version

* Wed Jun 17 2009 Slava Dubrovskiy <dubrsl@altlinux.ru> 1.6.2-alt1
- Build for ALT
